.. _spkg_pure_eval:

pure_eval: Safely evaluate AST nodes without side effects
===================================================================

Description
-----------

Safely evaluate AST nodes without side effects

License
-------

MIT

Upstream Contact
----------------

https://pypi.org/project/pure-eval/


Type
----

standard


Dependencies
------------

- $(PYTHON)
- :ref:`spkg_pip`

Version Information
-------------------

package-version.txt::

    0.2.2

version_requirements.txt::

    pure-eval


Equivalent System Packages
--------------------------

.. tab:: conda-forge

   .. CODE-BLOCK:: bash

       $ conda install pure_eval 


.. tab:: Fedora/Redhat/CentOS

   .. CODE-BLOCK:: bash

       $ sudo dnf install python3-pure-eval 


.. tab:: Gentoo Linux

   .. CODE-BLOCK:: bash

       $ sudo emerge dev-python/pure_eval 



If the system package is installed and if the (experimental) option
``--enable-system-site-packages`` is passed to ``./configure``, then ``./configure``
will check if the system package can be used.

